---
name: "🐛 Bug Report"
about: Create a report to help us improve the project
title: "[BUG] "
labels: bug, needs-triage
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots or Logs**
If applicable, add screenshots or log output to help explain your problem.

**System Details (please complete the following information):**
 - OS: [e.g. macOS, Ubuntu]
 - Version [e.g. 22.04]
